Module redhat — Inmanta 2017.2.1 documentation

# Module redhat

> - License: Apache 2.0
> - Version: 0.7.0
> - Author: Inmanta <code@inmanta.com>
> - Upstream project: https://github.com/inmanta/redhat.git

## Implementations

implementation `redhat::epel::epel7`

implementation `redhat::network::aliasImpl`

  This module implements the configuration for network interfaces on rhel

implementation `redhat::network::config`

  This is the configuration each redhat based operating system should have

implementation `redhat::network::ifaceImpl`

implementation `redhat::scl::epel7`